@@ -27,11 +27,12 @@
 #include <QStringList>
 #include <QDateTime>
 #include <QDebug>
+#include <stdexcept>
 
-class OrmException
+class OrmException : public std::runtime_error
 {
 public:
-    OrmException(const QString& text) : mText(text) {}
+    OrmException(const QString& text) : std::runtime_error(text.toStdString()), mText(text) {}
     virtual ~OrmException(){}
     virtual const QString& text() const { return mText; }
 private:
@@ -41,7 +42,7 @@ private:
 class OrmNoObjectException : public OrmException
 {
 public:
-    OrmNoObjectException() : OrmException("No object exception"){}
+    OrmNoObjectException() : OrmException("SQL query expects one record but found none."){}
     ~OrmNoObjectException(){}
 };
 
