@@ -28,6 +28,9 @@
 class SqlEngine : public QObject {
     Q_OBJECT
     public:
+        const QString DATE_FORMAT = "yyyy-MM-dd";
+        const QString TIME_FORMAT = "hh:mm";
+
         QString dbFilename; ///< database filename including path
         QSqlDatabase db; ///< this may be private one day...
 
@@ -65,6 +68,7 @@ class SqlEngine : public QObject {
 
         bool beginTransaction();
         bool commitTransaction();
+        bool rollbackTransaction();
 
         /// search Events for .... returns true if success
         bool searchEvent(int conferenceId, const QHash<QString,QString> &columns, const QString &keyword);
@@ -78,5 +82,24 @@ class SqlEngine : public QObject {
         void dbError(const QString& message);
 };
 
+
+class TransactionRaii {
+    SqlEngine& sqlEngine;
+    bool committed = false;
+public:
+    TransactionRaii(SqlEngine& sqlEngine): sqlEngine(sqlEngine) {
+        sqlEngine.beginTransaction();
+    }
+
+    void commit() {
+        sqlEngine.commitTransaction();
+        committed = true;
+    }
+
+    ~TransactionRaii() {
+        if (!committed) sqlEngine.rollbackTransaction();
+    }
+};
+
 #endif /* SQLENGINE_H */
 
